@@ -1,9 +1,9 @@
 use strict; use warnings;
 
 package Memoize::SDBM_File;
-our $VERSION = '1.09';
+our $VERSION = '1.11';
 
-use SDBM_File 1.01;
+use SDBM_File 1.01; # for EXISTS support
 our @ISA = qw(SDBM_File);
 
 1;
